.CodeMirror {
	border: 1px solid #ccc;
	border-radius: 4px;
	color: inherit;
	font-family: inherit;
	font-size: 14px;
	padding: 6px 8px;
	resize: both;
	width: 518px;
}

.CodeMirror-focused {
	border-color: #999;
}
